@@ -97,7 +97,8 @@ sub execute {
     $self->{response_content} = $self->_execute_http_request();
 
     if ( $DEBUG ) {
-        print STDERR $self->{response_content};
+        print STDERR $self->request_object->as_string();
+        print STDERR $self->response_object->as_string();
     }
 
 }
